# Meteo.LT Lithuanian weather forecast package
Python library for accessing Meteo.lt weather forecast data

Please visit https://api.meteo.lt/ for more information

If you want to contribute you can use devcontainers in vscode for easiest setup. Please see [instructions here](.devcontainer/README.md)
